@@ -16,7 +16,11 @@ from dbnd._core.task_run.log_preview import read_dbnd_log_preview
 from dbnd._core.tracking.airflow_dag_inplace_tracking import (
     calc_task_run_attempt_key_from_af_ti,
 )
-from dbnd._core.utils.uid_utils import get_uuid
+from dbnd._core.utils.uid_utils import (
+    get_airflow_instance_uid,
+    get_job_run_uid,
+    get_task_run_attempt_uid,
+)
 
 
 AIRFLOW_FILE_TASK_HANDLER = FileTaskHandler.__name__
@@ -77,7 +81,15 @@ class DbndAirflowHandler(logging.Handler):
 
         # communicate the task_run_attempt_uid to inner processes
         # will be used for the task_run of `<airflow_operator>_execute` task
-        self.task_run_attempt_uid = get_uuid()
+        airflow_instance_uid = get_airflow_instance_uid()
+        run_uid = get_job_run_uid(
+            airflow_instance_uid=airflow_instance_uid,
+            dag_id=ti.dag_id,
+            execution_date=ti.execution_date,
+        )
+        self.task_run_attempt_uid = get_task_run_attempt_uid(
+            run_uid, ti.dag_id, ti.task_id, ti.try_number,
+        )
         self.task_env_key = task_key
         os.environ[self.task_env_key] = str(self.task_run_attempt_uid)
 
